@@ -457,14 +457,18 @@ class CallTracer(vm.VirtualMachine):
     return classes
 
   def pytd_for_types(self, defs):
+    # If a variable is annotated, we'll always output that type.
+    annotated_names = set()
     data = []
     pytd_convert = self.convert.pytd_convert
-    annots = abstract_utils.get_annotations_dict(defs) or {}
-    for name, t in pytd_convert.uninitialized_annotations_to_instance_types(
-        self.exitpoint, annots, defs):
+    annots = abstract_utils.get_annotations_dict(defs)
+    for name, t in pytd_convert.annotations_to_instance_types(
+        self.exitpoint, annots):
+      annotated_names.add(name)
       data.append(pytd.Constant(name, t))
     for name, var in defs.items():
-      if name in output.TOP_LEVEL_IGNORE or self._is_builtin(name, var.data):
+      if (name in output.TOP_LEVEL_IGNORE or name in annotated_names or
+          self._is_builtin(name, var.data)):
         continue
       options = var.FilteredData(self.exitpoint, strict=False)
       if (len(options) > 1 and
@@ -582,7 +586,13 @@ class CallTracer(vm.VirtualMachine):
   def _check_return(self, node, actual, formal):
     if not self.options.report_errors:
       return True
-    bad = self.matcher.bad_matches(actual, formal, node)
+    views = abstract_utils.get_views([actual], node)
+    # Check for typevars in the return value first, since bad_matches
+    # expects not to get any.
+    bad = [view for view in views
+           if actual in view and view[actual].data.formal]
+    if not bad:
+      bad = self.matcher.bad_matches(actual, formal, node)
     if bad:
       with self.convert.pytd_convert.produce_detailed_output():
         combined = pytd_utils.JoinTypes(
